-- Simpler HUD
-- Version 1.2
-- By SteelT.
-- TehRealSalt's Custom HUD library is used.

-- Init script, sets up HUD items, cvars, plus helper functions, for mod support.
local SMPLH_CFGFILE = "client/simplerhud_conf.cfg"
local cvsetfunc = CV_Set;
rawset(_G, "SimplerHUD", {}) -- Setup global

SimplerHUD.version = "1.2"
SimplerHUD.modname = "simplerhud"

print("Simpler HUD version "..SimplerHUD.version)
print("Setting up SimplerHUD items...")
SimplerHUD.cvars = {}
SimplerHUD.cvars.faceflip = CV_RegisterVar({"smplh_flipface", "No", 0, CV_YesNo, nil})
SimplerHUD.patches = {} //

-- These load first so we can access some functions from the libs
dofile("customsave_io.lua")
dofile("CUSTOMHUDLIB.lua")

local function loadsettings(conf)
	if (cvsetfunc) then
		table.sort(SimplerHUD.cvars) -- Sort just in case
		for _k,v in pairs(SimplerHUD.cvars)
			local name = v.name
			CV_Set(v, SimplerHUD.conf[name])
		end
	else
		table.sort(conf) -- Same as above
		for k,v in pairs(conf) do
			COM_BufInsertText(consoleplayer, k.." "..v) 
		end
	end
end

local function SimplerHUD_LoadConf()
	if (I_FileExists(SMPLH_CFGFILE)) then
		SimplerHUD.conf = I_ReadSaveFile(SMPLH_CFGFILE)
		if (SimplerHUD.conf) then
			print("Loading SimplerHUD settings...")
			loadsettings(SimplerHUD.conf)
		end
	end
end

local function SimplerHUD_SaveConf()
	if (SimplerHUD.conf == nil)
		SimplerHUD.conf = {}
	end

	SimplerHUD.conf[SimplerHUD.cvars.faceflip.name] = SimplerHUD.cvars.faceflip.string
	I_WriteSaveFile(SMPLH_CFGFILE, SimplerHUD.conf)
end

customhud.SetupItem("simplescore", SimplerHUD.modname)
customhud.SetupItem("simpletime", SimplerHUD.modname)
customhud.SetupItem("simplerings", SimplerHUD.modname)
customhud.SetupItem("simplelives", SimplerHUD.modname)
customhud.SetupItem("simplebosscounter", SimplerHUD.modname)

function SimplerHUD.DisableAll()
	customhud.disable("simplescore")
	customhud.disable("simpletime")
	customhud.disable("simplerings")
	customhud.disable("simplelives")
	customhud.disable("simpleringsani")
	customhud.disable("simplebosscounter")
end

function SimplerHUD.EnableAll()
	customhud.enable("simplescore")
	customhud.enable("simpletime")
	customhud.enable("simplerings")
	customhud.enable("simplelives")
	customhud.enable("simpleringsani")
	customhud.enable("simplebosscounter")
end

addHook("GameQuit", function()
	SimplerHUD_SaveConf()
end)

function SimplerHUD.IsPatchValid(patch)
	local utype
	
	if (patch == nil)
		return false
	end
	
	utype = userdataType(patch)
	
	if (utype ~= "patch_t")
		error("bad argument #1 to 'IsPatchValid' (patch_t expected, got "..utype..")", 2)
	end
	return (patch and patch.valid)
end


-- Helper function to check for various kind of HUDs
local function CheckHUDs()	
	if (TOL_SPYRO)
		if (maptol & TOL_SPYRO)
			SimplerHUD.DisableAll()
		else
			SimplerHUD.EnableAll()
		end
	end

	if not (SimplerHUD.cv_hidetime)
		SimplerHUD.cv_hidetime = CV_FindVar("hidetime")
	end

	if not (SimplerHUD.cv_cooplives)
		SimplerHUD.cv_cooplives = CV_FindVar("cooplives")
	end

	-- Because some mods like to reset hud enables/disables every tic instead of once
	if (customhud.CheckType("simplescore") == SimplerHUD.modname) 
		hud.disable("score") 
	end
	
	if (customhud.CheckType("simpletime") == SimplerHUD.modname) 
		hud.disable("time") 
	end
	
	if (customhud.CheckType("simplerings") == SimplerHUD.modname) 
	or (customhud.CheckType("simpleringsani") == SimplerHUD.modname)
		hud.disable("rings")
	end
	
	if (customhud.CheckType("simplelives") == SimplerHUD.modname) 
		hud.disable("lives") 
	end
end

addHook("ThinkFrame", CheckHUDs)
SimplerHUD_LoadConf()
dofile("SMPL_Funcs.lua")
dofile("SMPL_Disp.lua")